# SLIPO API Python client

A simple Python client for [SLIPO API](https://github.com/SLIPO-EU).

The `SLIPO API` can be used to:

- Access the remote user file system to browse, upload and
  download files
- Query resource catalog and download RDF datasets. All data
  are encoded in `N-Triples` format
- Manage existing POI data integration processes
- Execute a single SLIPO Toolkit component operation. Currently,
  SLIPO supports `Transform`, `Interlink`, `Fuse` and `Enrichment`
  operations